
================
openwrt-luci-rpc
================


.. image:: https://img.shields.io/pypi/v/openwrt_luci_rpc.svg
        :target: https://pypi.python.org/pypi/openwrt_luci_rpc

.. image:: https://github.com/fbradyirl/openwrt-luci-rpc/workflows/.github/workflows/main.yml/badge.svg
        :target: https://github.com/fbradyirl/openwrt-luci-rpc/actions

.. image:: https://readthedocs.org/projects/openwrt-luci-rpc/badge/?version=latest
        :target: https://openwrt-luci-rpc.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


Python3 module for interacting with the OpenWrt Luci RPC interface

-  Free software: Apache Software License 2.0
-  Documentation: `https://openwrt-luci-rpc.readthedocs.io`_.
-  LuaDoc for the `Luci RPC APIs`_.

Features
--------

-  Allows you to use the Luci RPC interface to fetch connected devices
   on your OpenWrt based router.
-  Supports 15.X & 17.X & 18.X or newer releases of OpenWrt.


Development
~~~~~~~~~~~

See `contributing guide`_.

.. _`Luci RPC APIs`: https://htmlpreview.github.io/?https://raw.githubusercontent.com/openwrt/luci/master/docs/api/index.html
.. _`https://openwrt-luci-rpc.readthedocs.io`: https://openwrt-luci-rpc.readthedocs.io
.. _contributing guide: CONTRIBUTING.rst
